import {AUTH_LOGIN, AUTH_LOGOUT, AUTH_ERROR, AUTH_CHECK, AUTH_GET_PERMISSIONS} from 'react-admin';
import LocalStorage from '../../modules/localStorage/LocalStorage';

class AuthProvider {
    constructor() {
        this.localStorage = new LocalStorage();
    }

    authLogin(params) {
        this.localStorage.setItem('adminConnect', JSON.stringify(params));
        return Promise.resolve();
    }

    authLogout(params) {
        this.localStorage.removeItem('adminConnect');
        this.localStorage.removeItem('permissions');
        return Promise.resolve();
    }

    authError(params) {
        const status = params.status;
        if (status === 401 || status === 403) {
            this.localStorage.removeItem('adminConnect');
            return Promise.reject();
        }
        return Promise.resolve();
    }

    authCheck(params) {
        return this.localStorage.getItem('adminConnect') ? Promise.resolve() : Promise.reject();
    }

    authGetPermissions(params) {
        const {resource} = params;
        if (resource === 'promotions') {
            // check credentials for the promotions resource
            return Promise.resolve();
        }
        if (resource === 'mps') {
            // check credentials for the mps resource
            return Promise.resolve();
        }

        return Promise.reject();
    }

    init() {
        return (type, params, resources) => {
            if (type === AUTH_LOGIN) {
                return this.authLogin(params);
            }

            if (type === AUTH_LOGOUT) {
                return this.authLogout(params);
            }

            if (type === AUTH_ERROR) {
                return this.authError(params);
            }

            if (type === AUTH_CHECK) {
                return this.authCheck(params);
            }

            if (type === AUTH_GET_PERMISSIONS) {
                return this.authGetPermissions(params);
            }

            return Promise.reject('Unknown method');
        }
    }
}

export default AuthProvider;